@@ -1,5 +1,5 @@
 /* blue6.cxx
-     $Id: blue6.cxx,v 1.24 2001/07/23 01:55:05 elf Exp $
+     $Id: blue6.cxx,v 1.26 2003/05/27 16:30:25 elf Exp $
 
    written by Marc Singer
    22 February 1998
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    -----------
    DESCRIPTION
@@ -70,9 +72,9 @@
 inline int min (int a, int b) { if (a < b) return a; else return b; }
 inline int max (int a, int b) { if (a > b) return a; else return b; }
 
-Attribute Attribute::normal = Attribute (Attribute::BgDefault
-					 | Attribute::FgDefault,
-					 Attribute::All);
+Attribute Attribute::normal = Attribute (Attribute::_BgDefault
+					 | Attribute::_FgDefault,
+					 Attribute::_All);
 
 inline void send (const char* sz) {
   fprintf (stdout, sz);
@@ -118,50 +120,50 @@ int Attribute::reconcile (const Termcap& termcap, Attribute attr,
 		  | (attr.m_value &  attr.m_mask));
 
 				// Map bright colors to emboldend ones
-  if (attr.m_mask & FgBright)
-    attr.m_value = (   (attr.m_value & ~Bold)
-		    | ((attr.m_value &  FgBright) ? Bold : 0));
+  if (attr.m_mask & _FgBright)
+    attr.m_value = (   (attr.m_value & ~_Bold)
+		    | ((attr.m_value &  _FgBright) ? _Bold : 0));
 
 				// Disable attributes first
-  if (!(attr.m_value & Bold) && (m_value & Bold)) {
+  if (!(attr.m_value & _Bold) && (m_value & _Bold)) {
     cb += termcap.compose (termcapEndMode, sz + cb);
-    m_value &= ~(Bold | FgMask | BgMask);
+    m_value &= ~(_Bold | _FgMask | _BgMask);
   }
-  if (!(attr.m_value & Underline) && (m_value & Underline)) {
+  if (!(attr.m_value & _Underline) && (m_value & _Underline)) {
     if (termcap.has (termcapEndUnderline))
       cb += termcap.compose (termcapEndUnderline, sz + cb);
     else {
       cb += termcap.compose (termcapEndMode, sz + cb);
-      m_value &= ~(Underline | FgMask | BgMask);
+      m_value &= ~(_Underline | _FgMask | _BgMask);
     }
   }
-  if (!(attr.m_value & Inverse) && (m_value & Inverse)) {
+  if (!(attr.m_value & _Inverse) && (m_value & _Inverse)) {
     cb += termcap.compose (termcapEndMode, sz + cb);
-    m_value &= ~(Inverse | FgMask | BgMask);
+    m_value &= ~(_Inverse | _FgMask | _BgMask);
   }
-  if (!(attr.m_value & Standout) && (m_value & Standout)) {
+  if (!(attr.m_value & _Standout) && (m_value & _Standout)) {
     if (termcap.has (termcapEndStandout))
       cb += termcap.compose (termcapEndStandout, sz + cb);
     else {
       cb += termcap.compose (termcapEndMode, sz + cb);
-      m_value &= ~(Standout | FgMask | BgMask);
+      m_value &= ~(_Standout | _FgMask | _BgMask);
     }
   }
-  if (!(attr.m_value & Blink) && (m_value & Blink)) {
+  if (!(attr.m_value & _Blink) && (m_value & _Blink)) {
     cb += termcap.compose (termcapEndMode, sz + cb);
-    m_value &= ~(AllMode & ~(Blink | FgMask | BgMask));
+    m_value &= ~(_AllMode & ~(_Blink | _FgMask | _BgMask));
   }
 
 				// Enable missing attributes
-  if ((attr.m_value & Bold) && !(m_value & Bold))
+  if ((attr.m_value & _Bold) && !(m_value & _Bold))
     cb += termcap.compose (termcapStartBold, sz + cb);
-  if ((attr.m_value & Underline) && !(m_value & Underline))
+  if ((attr.m_value & _Underline) && !(m_value & _Underline))
     cb += termcap.compose (termcapStartUnderline, sz + cb);
-  if ((attr.m_value & Inverse) && !(m_value & Inverse))
+  if ((attr.m_value & _Inverse) && !(m_value & _Inverse))
     cb += termcap.compose (termcapStartInverse, sz + cb);
-  if ((attr.m_value & Standout) && !(m_value & Standout))
+  if ((attr.m_value & _Standout) && !(m_value & _Standout))
     cb += termcap.compose (termcapStartStandout, sz + cb);
-  if ((attr.m_value & Blink) && !(m_value & Blink))
+  if ((attr.m_value & _Blink) && !(m_value & _Blink))
     cb += termcap.compose (termcapStartBlink, sz + cb);
 
 				// Set color attribute
@@ -169,19 +171,19 @@ int Attribute::reconcile (const Termcap& termcap, Attribute attr,
     ? termcapSetAnsiForeground : termcapSetForeground;
   int idBg = termcap.has (termcapSetAnsiBackground)
     ? termcapSetAnsiBackground : termcapSetBackground;
-  if ((attr.m_value & FgMask) != (m_value & FgMask)) {
-    unsigned16 color = (attr.m_value & FgMask);
-    if (color == FgDefault)
+  if ((attr.m_value & _FgMask) != (m_value & _FgMask)) {
+    unsigned16 color = (attr.m_value & _FgMask);
+    if (color == _FgDefault)
       cb += termcap.compose (idFg, sz + cb, 9);
     else
-      cb += termcap.compose (idFg, sz + cb, (color - FgFirst) >> FgShift);
+      cb += termcap.compose (idFg, sz + cb, (color - _FgFirst) >> _FgShift);
   }
-  if ((attr.m_value & BgMask) != (m_value & BgMask)) {
-    unsigned16 color = (attr.m_value & BgMask);
-    if (color == BgDefault)
+  if ((attr.m_value & _BgMask) != (m_value & _BgMask)) {
+    unsigned16 color = (attr.m_value & _BgMask);
+    if (color == _BgDefault)
       cb += termcap.compose (idBg, sz + cb, 9);
     else
-      cb += termcap.compose (idBg, sz + cb, (color - BgFirst) >> BgShift);
+      cb += termcap.compose (idBg, sz + cb, (color - _BgFirst) >> _BgShift);
   }
 
   assert_ (cb < cbMax);		// *** FIXME *** need something better
@@ -354,10 +356,10 @@ int Pane::prompt (Position pos, const char* szPrompt,
   pos.m_x += strlen (szPrompt);
 
   int ibSelect = 0, cbSelect = strlen (szResponse);
-  attr ().invert (Attribute::Inverse);
+  attr ().invert (Attribute::_Inverse);
   // on (A_REVERSE);
   draw_text (pos, szResponse);
-  attr ().ignore (Attribute::Inverse);
+  attr ().ignore (Attribute::_Inverse);
   //  off (A_REVERSE);
 
   int point = 0;
@@ -472,10 +474,10 @@ int Pane::prompt (Position pos, const char* szPrompt,
     // FIXME: We need to break-up the display so we show the
     //        highlighted portion AND the unhighlighted portion.
     if (cbSelect)
-      attr ().invert (Attribute::Inverse);
+      attr ().invert (Attribute::_Inverse);
     //      on (A_REVERSE);
     else
-      attr ().ignore (Attribute::Inverse);
+      attr ().ignore (Attribute::_Inverse);
     //      off (A_REVERSE);
 				// Check for scroll changes
     while (point - scroll >= dx () - pos.m_x)
@@ -487,7 +489,7 @@ int Pane::prompt (Position pos, const char* szPrompt,
 	       szResponse + scroll);
 //    printfxy (x, y, "%-*.*s", dx () - x, dx () - x, szResponse + scroll);
     if (cbSelect)
-      attr ().ignore (Attribute::Inverse);
+      attr ().ignore (Attribute::_Inverse);
     //      off (A_REVERSE);
   }
 
