@@ -1,5 +1,5 @@
 /* blue6.h					-*- C++ -*-
-   $Id: blue6.h,v 1.17 2001/07/23 01:55:05 elf Exp $
+   $Id: blue6.h,v 1.19 2003/05/27 16:30:25 elf Exp $
    
    written by Marc Singer
    22 Feb 1998
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    Simple that classs to interface to termcap.
 
@@ -53,41 +55,44 @@ public:
   static Attribute normal;	// Used to reset attributes
 
   enum eAttr {
-    Plain		= 0x0000,
-    Bold		= 0x0001,
-    Underline		= 0x0002,
-    Inverse		= 0x0004,
-    Reverse		= 0x0004,
-    Standout		= 0x0008,
-    Blink		= 0x0010,
+    // *** The preceeding underscores are to work around a CPP bug
+    // that doesn't permit parameter pasting to a class specifier.  We
+    // cannot append Attribute:: to one of these identifiers.
+    _Plain		= 0x0000,
+    _Bold		= 0x0001,
+    _Underline		= 0x0002,
+    _Inverse		= 0x0004,
+    _Reverse		= 0x0004,
+    _Standout		= 0x0008,
+    _Blink		= 0x0010,
     //    Dim		= 0x0020,
-    AllMode		= 0x003f,
-    FgBright		= 0x0080,
-    FgDefault		= 0x0000,	// Foreground colors
-    FgMask		= 0x0f00,
-    FgShift		= 8,
-    FgFirst		= 0x0100,
-    FgBlack		= 0x0100,
-    FgRed		= 0x0200,
-    FgGreen		= 0x0300,
-    FgYellow		= 0x0400,
-    FgBlue		= 0x0500,
-    FgMagenta		= 0x0600,
-    FgCyan		= 0x0700,
-    FgWhite		= 0x0800,
-    BgMask		= 0xf000, 	// Background colors
-    BgShift		= 12,
-    BgDefault		= 0x0000,
-    BgFirst		= 0x1000,
-    BgBlack		= 0x1000,
-    BgRed		= 0x2000,
-    BgGreen		= 0x3000,
-    BgYellow		= 0x4000,
-    BgBlue		= 0x5000,
-    BgMagenta		= 0x6000,
-    BgCyan		= 0x7000,
-    BgWhite		= 0x8000,
-    All			= 0xff3f,
+    _AllMode		= 0x003f,
+    _FgBright		= 0x0080,
+    _FgDefault		= 0x0000,	// Foreground colors
+    _FgMask		= 0x0f00,
+    _FgShift		= 8,
+    _FgFirst		= 0x0100,
+    _FgBlack		= 0x0100,
+    _FgRed		= 0x0200,
+    _FgGreen		= 0x0300,
+    _FgYellow		= 0x0400,
+    _FgBlue		= 0x0500,
+    _FgMagenta		= 0x0600,
+    _FgCyan		= 0x0700,
+    _FgWhite		= 0x0800,
+    _BgMask		= 0xf000, 	// Background colors
+    _BgShift		= 12,
+    _BgDefault		= 0x0000,
+    _BgFirst		= 0x1000,
+    _BgBlack		= 0x1000,
+    _BgRed		= 0x2000,
+    _BgGreen		= 0x3000,
+    _BgYellow		= 0x4000,
+    _BgBlue		= 0x5000,
+    _BgMagenta		= 0x6000,
+    _BgCyan		= 0x7000,
+    _BgWhite		= 0x8000,
+    _All		= 0xff3f,
   };
 
 protected:
@@ -108,7 +113,7 @@ public:
 
   int reconcile (const Termcap& termcap, Attribute attr, char* sz, int cbMax);
   void set (int attr) {
-    m_value = attr; m_mask = (AllMode | BgMask | FgMask); }
+    m_value = attr; m_mask = (_AllMode | _BgMask | _FgMask); }
   void clear (void) {
     m_value = m_mask = 0; }
   int value (void) const {
