@@ -1,5 +1,5 @@
 /* curves.cxx
-     $Id: curves.cxx,v 1.42 1998/09/06 21:46:23 elf Exp $
+     $Id: curves.cxx,v 1.46 2003/08/21 04:40:23 elf Exp $
 
    written by Marc Singer
    20 September 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    -----------
    DESCRIPTION
@@ -103,6 +105,42 @@ int LCurves::_classify (FILE_INFO* pInfo)
 }
 
 
+/* LCurves::copy_name_escaped
+
+   performs a simple strcpy, inserting appropriate escape characters
+   when the name will confuse the system() call.
+
+*/
+
+int LCurves::copy_name_escaped (char* szDst, const char* szSrc)
+{
+  if (szDst == NULL || szSrc == NULL || !*szSrc)
+    return 0;
+
+  szDst += strlen (szDst);
+  int cb = 0;
+  for (; *szSrc; ++szSrc) {
+    switch (*szSrc) {
+    case ' ':
+    case '\t':
+    case '\\':
+    case '&':
+    case ';':
+      *szDst++ = '\\';
+      *szDst++ = *szSrc;
+      cb += 2;
+      break;
+    default:
+      *szDst++ = *szSrc;
+      cb += 1;
+      break;
+    }
+  }
+  *szDst = 0;
+  return cb;
+}
+
+
 /* LCurves::do_directory_change
 
    change to currently selected directory.
@@ -422,7 +460,7 @@ void LCurves::init_colors (void)
     m_color_scheme = 2;
 
 #define _DEF_COLOR(cl,fg,bg,m) m_rgattrClass[(cl)].set \
-  	(Attribute::##fg | Attribute::##bg | Attribute::##m)
+  	(Attribute::_##fg | Attribute::_##bg | Attribute::_##m)
 
   switch (m_color_scheme) {
   default:
@@ -503,6 +541,11 @@ void LCurves::init_colors (void)
    If there were no files that match the selection criteria the
    returned pointer will be NULL.
 
+   The names are appropriately escaped as to be compatible with
+   system() calls.  The *2 factors during allocation are to leave room
+   for all characters being escaped in each directory and name--an
+   unlikely occurrence, but best to be safe.
+
 */
 
 char* LCurves::name_files (bool fFilenameOnly, int flagMask, int flagSet)
@@ -512,8 +555,9 @@ char* LCurves::name_files (bool fFilenameOnly, int flagMask, int flagSet)
 		? (m_cFilesTagged ? m_cFilesTagged : 1)
 		: m_cFiles);
   char* szFiles
-    = (char*) malloc (cFiles*((fFilenameOnly ? 0 : strlen (m_dir.path ()) + 1)
-			      + m_cchFilenameMax + 1));
+    = (char*) malloc (cFiles*((fFilenameOnly ? 0 : strlen (m_dir.path ())*2 + 1)
+			      + m_cchFilenameMax*2
+			      + 1));
   *szFiles = 0;
 
 				// -- Special case for selecting for
@@ -524,10 +568,10 @@ char* LCurves::name_files (bool fFilenameOnly, int flagMask, int flagSet)
     if ((m_cvs.flags (_idx_file (m_iFileCursor)) & flagMask) == flagSet) {
       m_dir.stat (_idx_file (m_iFileCursor));
       if (!fFilenameOnly) {
-	strcat (szFiles, m_dir.path ());
+	copy_name_escaped (szFiles, m_dir.path ());
 	strcat (szFiles, "/");
       }
-      strcat (szFiles, _file (m_iFileCursor));
+      copy_name_escaped (szFiles, _file (m_iFileCursor));
     }
   }
 				// -- Normal case for selecting
@@ -538,10 +582,10 @@ char* LCurves::name_files (bool fFilenameOnly, int flagMask, int flagSet)
 	continue;
       m_dir.stat (_idx_file (iFile));
       if (!fFilenameOnly) {
-	strcat (szFiles, m_dir.path ());
+	copy_name_escaped (szFiles, m_dir.path ());
 	strcat (szFiles, "/");
       }
-      strcat (szFiles, _file (iFile));
+      copy_name_escaped (szFiles, _file (iFile));
       strcat (szFiles, " ");
     }
   }
@@ -866,6 +910,11 @@ void LCurves::save (void)
   win.activate (false);
 }
 
+bool LCurves::can_select_pane (int iPane)
+{
+  return iPane == 0 || _idx_file (0) < m_dir.count_files ();
+}
+
 void LCurves::select_pane (int iPane)
 {
   if (iPane != m_iPane) {
