@@ -1,5 +1,5 @@
 /* debug.h				-*- C++ -*-
-   $Id: debug.h,v 1.12 2001/03/25 23:50:59 elf Exp $
+   $Id: debug.h,v 1.13 2001/11/27 23:57:36 elf Exp $
    
    written by Marc Singer
    21 Oct 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
 */
 
