@@ -1,5 +1,5 @@
 /* file.h
-   $Id: file.h,v 1.3 1996/10/30 09:37:15 elf Exp $
+   $Id: file.h,v 1.5 2001/11/28 00:23:21 elf Exp $
    
    written by Marc Singer
    25 Oct 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
 */
 
