@@ -1,5 +1,5 @@
 /* main.cxx
-     $Id: main.cxx,v 1.54 2001/10/20 19:31:04 elf Exp $
+     $Id: main.cxx,v 1.56 2003/08/21 04:40:23 elf Exp $
 
    written by Marc Singer
    12 August 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    -----------
    DESCRIPTION
@@ -231,7 +233,11 @@ int main (int argc, char** argv)
       break;
 
     case MENU_ID (menuMain, '\t'):
-      curves.select_pane (curves.pane () ? 0 : 1);
+      {
+	int iPane = curves.pane () ? 0 : 1;
+	if (curves.can_select_pane (iPane))
+	  curves.select_pane (iPane);
+      }
       break;
 
     case MENU_ID (menuMain, '\f'):
