@@ -1,5 +1,5 @@
 /* mman.h
-   $Id: mman.h,v 1.2 1998/09/07 00:49:33 elf Exp $
+   $Id: mman.h,v 1.3 2001/11/27 23:57:36 elf Exp $
    
    written by Marc Singer
    11 Nov 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    This is an intermediate memory manager header that allows us to
    declare constants that may not be present on some machines.
