@@ -1,5 +1,5 @@
 /* signal.cxx
-     $Id: signal.cxx,v 1.5 2001/10/20 19:31:04 elf Exp $
+     $Id: signal.cxx,v 1.7 2002/09/07 16:40:15 elf Exp $
 
    written by Marc Singer
    18 October 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    -----------
    DESCRIPTION
@@ -112,6 +114,16 @@
 #include "signal.h"
 
 
+	// Macros for blocking signals while we process
+#define BLOCK(s) \
+  sigset_t _sigset, _sigsetOld; \
+  sigemptyset (&_sigset); \
+  sigaddset (&_sigset, (s)); \
+  sigprocmask (SIG_BLOCK, &_sigset, &_sigsetOld)
+#define UNBLOCK \
+  sigprocmask (SIG_SETMASK, &_sigsetOld, &_sigset)
+
+
 LSignalHandlerInstance* LSignal::g_rgpHandler[NSIG];
 struct sigaction LSignal::g_rgAction[NSIG];
 sigset_t LSignal::g_setEnable;
@@ -150,8 +162,10 @@ int LSignal::accept (int signal, LSignalHandler pfn, void* pv,
     ppSig = &(*ppSig)->pNext;
 
 				// -- Link
+  BLOCK(signal);
   pSig->pNext = (*ppSig);
   *ppSig = pSig;
+  UNBLOCK;
 
   enable (signal);
   return 0;
