@@ -1,5 +1,5 @@
 /* version.h
-     $Id: version.h,v 1.11 2001/03/25 18:10:14 elf Exp $
+     $Id: version.h,v 1.13 2003/05/27 16:36:20 elf Exp $
 
    written by Marc Singer
    29 September 1996
@@ -20,9 +20,11 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   in a file called COPYING along with this program; if not, write to
-   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
-   02139, USA.
+   with your Debian GNU/Linux system, in
+   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
+   source package as the file COPYING. If not, write to the Free
+   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
+   02111-1307, USA.
 
    -----------
    DESCRIPTION
@@ -42,7 +44,7 @@
 */
 
 # include "_version.h"
-# define SZ_COPYRIGHT "Copyright (C) 1996-2001 by Marc Singer"
+# define SZ_COPYRIGHT "Copyright (C) 1996-2003 by Marc Singer"
 
  const char* g_szVersion = SZ_VERSION;
  const char* g_szCopyright = SZ_COPYRIGHT;
